@@ -2,7 +2,7 @@ from datetime import datetime
 
 from django.core.management.base import BaseCommand
 
-from account.models import AuthKey
+from urlauth.models import AuthKey
 
 class Command(BaseCommand):
     help = 'Remove expired keys from database'
